import 'package:flex/expose_flutter.dart';
import 'package:flex/flex.dart';

import 'test_core.dart';

Future<void> main() async {
  await Runner([
    Group(
      id: 'ansi',
      description: 'Tests relating to [AnsiColor] and other ansi helpers.',
      children: [
        Test(
          id: 'foreground',
          description: 'Testing that [Color.ansiWrap] in foreground mode works as intended.',
          function: (pause, resume) async {
            try {
              assert(const Color(0xFFFFFFFF).ansiWrap('ansi foreground') == '\x1b[38;2;255;255;255m' 'ansi foreground' '\x1b[39m', 'ansiWrap must return expected result.');
            } on AssertionError catch (e) {
              return AssertionTestResult('waiting_nosync', e);
            } catch (e, st) {
              return ErrorTestResult('waiting_nosync', e, st);
            }

            return const SuccessTestResult('waiting_nosync');
          },
        ),
        Test(
          id: 'transparent_foreground',
          description: 'Testing that [Color.ansiWrap] in foreground mode with full transparency works as intended.',
          function: (pause, resume) async {
            try {
              assert(const Color(0x00FFFFFF).ansiWrap('ansi foreground') == '\x1b[39m' 'ansi foreground', 'ansiWrap must return expected result.');
            } on AssertionError catch (e) {
              return AssertionTestResult('waiting_nosync', e);
            } catch (e, st) {
              return ErrorTestResult('waiting_nosync', e, st);
            }

            return const SuccessTestResult('waiting_nosync');
          },
        ),
        Test(
          id: 'background',
          description: 'Testing that [Color.ansiWrap] in background mode works as intended.',
          function: (pause, resume) async {
            try {
              assert(const Color(0xFFFFFFFF).ansiWrap('ansi background', bg: true) == '\x1b[48;2;255;255;255m' 'ansi background' '\x1b[49m', 'ansiWrap must return expected result.');
            } on AssertionError catch (e) {
              return AssertionTestResult('waiting_nosync', e);
            } catch (e, st) {
              return ErrorTestResult('waiting_nosync', e, st);
            }

            return const SuccessTestResult('waiting_nosync');
          },
        ),
        Test(
          id: 'transparent_background',
          description: 'Testing that [Color.ansiWrap] in background mode with full transparency works as intended.',
          function: (pause, resume) async {
            try {
              assert(const Color(0x00FFFFFF).ansiWrap('ansi background', bg: true) == '\x1b[49m' 'ansi background', 'ansiWrap must return expected result.');
            } on AssertionError catch (e) {
              return AssertionTestResult('waiting_nosync', e);
            } catch (e, st) {
              return ErrorTestResult('waiting_nosync', e, st);
            }

            return const SuccessTestResult('waiting_nosync');
          },
        ),
      ],
    ),
  ]).test();
}
