import 'package:flex/flex.dart';

import 'test_core.dart';

Future<void> main() async {
  await Runner([
    Group(
      id: 'string_extensions',
      description: 'Tests relating to extension methods on [String]s.',
      children: [
        Test(
          id: 'template',
          // TODO: Add test description.
          description: '',
          function: (pause, resume) async {
            try {
              assert(r'Hello, $name!'.fillTemplate({'name': 'World'}) == 'Hello, World!', 'When using a map containing all keys used in a template, keys should be replaced with values in the result.');
            } on AssertionError catch (e) {
              return AssertionTestResult('waiting_nosync', e);
            } catch (e, st) {
              return ErrorTestResult('waiting_nosync', e, st);
            }

            return const SuccessTestResult('waiting_nosync');
          },
        ),
        Test(
          id: 'template_missing',
          // TODO: Add test description.
          description: '',
          function: (pause, resume) async {
            try {
              assert(r'Hello, $name! You are $age years old.'.fillTemplate({'name': 'World'}) == r'Hello, World! You are {ERROR: Substitution for key $age not found} years old.', 'When using a map missing keys used in a template, missing keys should be left unformatted in the result.');
            } on AssertionError catch (e) {
              return AssertionTestResult('waiting_nosync', e);
            } catch (e, st) {
              return ErrorTestResult('waiting_nosync', e, st);
            }

            return const SuccessTestResult('waiting_nosync');
          },
        ),
        Test(
          id: 'template_escaped',
          // TODO: Add test description.
          description: '',
          function: (pause, resume) async {
            try {
              // Source: [https://en.wikipedia.org/wiki/Donald_Trump#Wealth](https://en.wikipedia.org/wiki/Donald_Trump#Wealth)
              // assert(r'In October 2018, The New York Times reported that $name "was a millionaire by age $age", borrowed at least \$$initial_amount million from his father, largely failed to reimburse him,' r" and had received \$$final_amount million (adjusted for inflation) from his father's business empire over his lifetime.".fillTemplate({'name': 'Trump', 'age': 8, 'initial_amount': 60, 'final_amount': 413}) == 'In October 2018, The New York Times reported that Trump "was a millionaire by age 8", borrowed at least \$60 million from his father, largely failed to reimburse him, and had received \$413 million (adjusted for inflation) from his father\'s business empire over his lifetime.', 'Escaped `\$` should be ignored.');
              assert(r"Hey, $name, I got \$$amount!".fillTemplate({'name': 'Jack', 'amount': 100}) == r'Hey, Jack, I got $100!', 'Escaped `\$` should be left as is.');
            } on AssertionError catch (e) {
              return AssertionTestResult('waiting_nosync', e);
            } catch (e, st) {
              return ErrorTestResult('waiting_nosync', e, st);
            }

            return const SuccessTestResult('waiting_nosync');
          },
        ),
        Test(
          id: 'template_variable_at_start',
          // TODO: Add test description.
          description: '',
          function: (pause, resume) async {
            try {
              assert(r"$name! Hey, $name, I'm talking to you!".fillTemplate({'name': 'Jack'}) == "Jack! Hey, Jack, I'm talking to you!", 'Variables should work when at the beginning of a string.');
            } on AssertionError catch (e) {
              return AssertionTestResult('waiting_nosync', e);
            } catch (e, st) {
              return ErrorTestResult('waiting_nosync', e, st);
            }

            return const SuccessTestResult('waiting_nosync');
          },
        ),
      ],
    ),
  ]).test();
}
